[Scummvm-cvs-logs] SF.net SVN: scummvm:[55804] scummvm/trunk/engines/hugo

fuzzie at users.sourceforge.net fuzzie at users.sourceforge.net
Mon Feb 7 17:39:10 CET 2011


Revision: 55804
          http://scummvm.svn.sourceforge.net/scummvm/?rev=55804&view=rev
Author:   fuzzie
Date:     2011-02-07 16:39:10 +0000 (Mon, 07 Feb 2011)

Log Message:
-----------
HUGO: Spelling fix.

Modified Paths:
--------------
    scummvm/trunk/engines/hugo/display.cpp
    scummvm/trunk/engines/hugo/display.h

Modified: scummvm/trunk/engines/hugo/display.cpp
===================================================================
--- scummvm/trunk/engines/hugo/display.h	2011-02-07 13:49:03 UTC (rev 55803)
+++ scummvm/trunk/engines/hugo/display.h	2011-02-07 16:39:10 UTC (rev 55804)
@@ -148,7 +148,7 @@
 
 	inline bool isInX(const int16 x, const rect_t *rect) const;
 	inline bool isInY(const int16 y, const rect_t *rect) const;
-	inline bool isOverlaping(const rect_t *rectA, const rect_t *rectB) const;
+	inline bool isOverlapping(const rect_t *rectA, const rect_t *rectB) const;
 
 	bool fontLoadedFl[kNumFonts];
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/hugo/display.cpp	2011-02-07 13:49:03 UTC (rev 55803)
+++ scummvm/trunk/engines/hugo/display.cpp	2011-02-07 16:39:10 UTC (rev 55804)
@@ -281,7 +281,7 @@
 		rect_t *bp = blist;
 		for (int16 b = 0; b < blen; b++, bp++) {
 			if (bp->dx)                             // blist entry used
-				if (isOverlaping(list, bp))
+				if (isOverlapping(list, bp))
 					coalesce[c++] = b;
 		}
 
@@ -623,9 +623,9 @@
 }
 
 /**
 * Check if two rectangles are over lapping
 */
-bool Screen::isOverlaping(const rect_t *rectA, const rect_t *rectB) const {
+bool Screen::isOverlapping(const rect_t *rectA, const rect_t *rectB) const {
 	return (isInX(rectA->x, rectB) || isInX(rectA->x + rectA->dx, rectB) || isInX(rectB->x, rectA) || isInX(rectB->x + rectB->dx, rectA)) && 
 		   (isInY(rectA->y, rectB) || isInY(rectA->y + rectA->dy, rectB) || isInY(rectB->y, rectA) || isInY(rectB->y + rectB->dy, rectA));
 }
@@ -623,9 +623,9 @@
 
 /**
-* Check if two rectangles are over lapping
+* Check if two rectangles are overlapping
 */

Modified: scummvm/trunk/engines/hugo/display.h
===================================================================